From: Oliver Hartkopp <oliver@hartkopp.net>
To: David Miller <davem@davemloft.net>, Neil Horman <nhorman@tuxdriver.com>
Cc: Linux Netdev List <netdev@vger.kernel.org>
Subject: [PATCH 2.6.30] Network Drop Monitor: Make use of consume_skb() in af_can.c
Date: Thu, 16 Apr 2009 21:58:29 +0200 [thread overview]
Message-ID: <49E78DE5.10104@hartkopp.net> (raw)
[-- Attachment #1: Type: text/plain, Size: 470 bytes --]
Since commit ead2ceb0ec9f85cff19c43b5cdb2f8a054484431 so called end-of-line
points for skb's should use consume_skb() to free the socket buffer.
In opposite to consume_skb() the function kfree_skb() is intended to be used
for unexpected skb drops e.g. in error conditions that now can trigger the
network drop monitor if enabled.
This patch moves the skb end-of-line point in af_can.c to use consume_skb().
Signed-off-by: Oliver Hartkopp <oliver@hartkopp.net>
---
[-- Attachment #2: can_consume_skb.patch --]
[-- Type: text/x-patch, Size: 438 bytes --]
diff --git a/net/can/af_can.c b/net/can/af_can.c
index 547bafc..10f0528 100644
--- a/net/can/af_can.c
+++ b/net/can/af_can.c
@@ -674,8 +674,8 @@ static int can_rcv(struct sk_buff *skb, struct net_device *dev,
rcu_read_unlock();
- /* free the skbuff allocated by the netdevice driver */
- kfree_skb(skb);
+ /* consume the skbuff allocated by the netdevice driver */
+ consume_skb(skb);
if (matches > 0) {
can_stats.matches++;
next reply other threads:[~2009-04-16 19:58 UTC|newest]
Thread overview: 13+ messages / expand[flat|nested] mbox.gz Atom feed top
2009-04-16 19:58 Oliver Hartkopp [this message]
2009-04-17 8:38 ` [PATCH 2.6.30] Network Drop Monitor: Make use of consume_skb() in af_can.c David Miller
2009-04-17 8:56 ` [PATCH] loopback: packet drops accounting Eric Dumazet
2009-04-17 8:59 ` David Miller
2009-04-17 9:27 ` Eric Dumazet
2009-04-17 10:06 ` [PATCH] loopback: better handling of packet drops Eric Dumazet
2009-04-17 10:33 ` Eric Dumazet
2009-04-17 10:51 ` David Miller
2009-04-17 12:22 ` Eric Dumazet
2009-04-17 14:58 ` Stephen Hemminger
2009-04-17 15:05 ` Eric Dumazet
2009-04-18 8:03 ` [PATCH] loopback: packet drops accounting Eric Dumazet
2009-04-20 9:26 ` David Miller
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=49E78DE5.10104@hartkopp.net \
--to=oliver@hartkopp.net \
--cc=davem@davemloft.net \
--cc=netdev@vger.kernel.org \
--cc=nhorman@tuxdriver.com \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.